==> icinga2confgen-0.0.7.post7-py3-none-any.whl: icinga2confgen/Commands/MonitoringPlugins/PathExistsCommand.py <==
#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Commands.MonitoringPlugins.MonitoringPluginCommand import MonitoringPluginCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.ValueChecker import ValueChecker


class PathExistsCommand(MonitoringPluginCommand):

    def __init__(self, id):
        MonitoringPluginCommand.__init__(self, id)

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        command = None if force_create else ConfigBuilder.get_command(id)
        if None is command:
            command = PathExistsCommand(id)
            ConfigBuilder.add_command(id, command)
        elif not isinstance(command, PathExistsCommand):
            raise Exception('Id must be for an instance of PathExistCommand but other instance is returned')

        return command

    def get_command(self):
        return 'check_path_exists.sh'

    def get_arguments(self):
        config = """{
    "-f" = {
      value = "$command_path_exist_file$"
    }
    "-d" = {
      value = "$command_path_exist_dir$"
    }
    "-i" = {
      set_if = "$command_path_exist_invert$"
    }
  }
"""

        return config

==> icinga2confgen-0.0.8.post1-py3-none-any.whl: icinga2confgen/Commands/MonitoringPlugins/PathExistsCommand.py <==
#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Commands.MonitoringPlugins.MonitoringPluginCommand import MonitoringPluginCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.ValueChecker import ValueChecker


class PathExistsCommand(MonitoringPluginCommand):

    def __init__(self, id: str):
        MonitoringPluginCommand.__init__(self, id)

    @staticmethod
    def create(id: str, force_create: bool = False):
        ValueChecker.validate_id(id)
        command = None if force_create else ConfigBuilder.get_command(id)
        if None is command:
            command = PathExistsCommand(id)
            ConfigBuilder.add_command(id, command)
        elif not isinstance(command, PathExistsCommand):
            raise Exception('Id must be for an instance of PathExistsCommand but other instance is returned')

        return command

    def get_command(self) -> str:
        return 'check_path_exists.sh'

    def get_arguments(self) -> str:
        config = """{
    "-f" = {
      value = "$command_path_exists_file$"
    }
    "-d" = {
      value = "$command_path_exists_dir$"
    }
    "-i" = {
      set_if = "$command_path_exists_invert$"
    }
  }
"""

        return config
